@@ -564,6 +564,9 @@ int TheengsDecoder::decodeBLEJson(JsonObject& jsondata) {
           case 16:
             doc["type"] = "TRACK"; // Bluetooth tracker
             break;
+          case 17:
+            doc["type"] = "BTN"; // Button
+            break;
           case 254:
             doc["type"] = "RMAC"; // random MAC address devices
             break;
@@ -579,7 +582,8 @@ int TheengsDecoder::decodeBLEJson(JsonObject& jsondata) {
         }
 
         // Octet Byte[1] bits[7-0] - True/False tags
-        if (tagstring.length() >= 4) { // bits[3-0]
+        if (tagstring.length() >= 4) { 
+          // bits[3-0]
           uint8_t data = getBinaryData(tagstring[3]);
 
           if (((data >> 0) & 0x01) == 1) { // CIDC - NOT Company ID Compliant
@@ -605,6 +609,14 @@ int TheengsDecoder::decodeBLEJson(JsonObject& jsondata) {
             doc["track"] = true;
             jsondata["track"] = doc["track"];
           }
+          // bits[7-4]
+          data = getBinaryData(tagstring[2]);
+
+          if (((data >> 0) & 0x01) == 1) { // Encrypted device data
+            doc.add("encr");
+            doc["encr"] = true;
+            jsondata["encr"] = doc["encr"];
+          }
         }
       }
 
@@ -784,6 +796,35 @@ int TheengsDecoder::decodeBLEJson(JsonObject& jsondata) {
             }
 
             std::string value(src + decoder[2].as<int>(), decoder[3].as<int>());
+            jsondata[sanitizeJsonKey(kv.key().c_str())] = value;
+            success = i_main;
+          } else if (strstr((const char*)decoder[0], "mac_from_hex_data") != nullptr) {
+            const char* src = svc_data;
+            if (strstr((const char*)decoder[1], MFG_DATA)) {
+              src = mfg_data;
+            }
+
+            std::string value(src + decoder[2].as<int>(), 12);
+
+            // reverse MAC
+            if (strstr((const char*)decoder[0], "revmac_from_hex_data") != nullptr) {
+              const char* mac_string = nullptr;
+              mac_string = value.c_str();
+              char* reverse_mac_string = (char*)malloc(strlen(mac_string) + 1);
+              reverse_hex_data(mac_string, reverse_mac_string, 12);
+              value = reverse_mac_string;
+            }
+
+            // upper case MAC
+            for (int x = 0; x <= 12; x++) {
+              value[x] = toupper(value[x]);
+            }
+
+            // add colons
+            for (int x = 2; x <= 14; x += 3) {
+              value.insert(x, 1, ':');
+            }
+
             jsondata[sanitizeJsonKey(kv.key().c_str())] = value;
             success = i_main;
           }
